@@ -2,7 +2,6 @@ import logging
 from typing import Optional
 
 from the_spymaster_util.http.base_client import BaseHttpClient
-from the_spymaster_util.logger import wrap
 from urllib3 import Retry
 
 from .structs import (
@@ -13,6 +12,7 @@ from .structs import (
     LoadModelsRequest,
     LoadModelsResponse,
 )
+from .structs.errors import SERVICE_ERRORS
 
 log = logging.getLogger(__name__)
 DEFAULT_BASE_URL = "http://localhost:5000"
@@ -26,20 +26,17 @@ DEFAULT_RETRY_STRATEGY = Retry(
 
 
 class TheSpymasterSolversClient(BaseHttpClient):
-    def __init__(self, base_url: str = None, retry_strategy: Optional[Retry] = DEFAULT_RETRY_STRATEGY):
-        if not base_url:
-            base_url = DEFAULT_BASE_URL
-        super().__init__(base_url=base_url, retry_strategy=retry_strategy)
-        log.debug(f"Solvers client is using backend: {wrap(self.base_url)}")
+    def __init__(self, base_url: str = DEFAULT_BASE_URL, retry_strategy: Optional[Retry] = DEFAULT_RETRY_STRATEGY):
+        super().__init__(base_url=base_url, retry_strategy=retry_strategy, common_errors=SERVICE_ERRORS)
 
     def generate_hint(self, request: GenerateHintRequest) -> GenerateHintResponse:
-        data = self._post("generate-hint", data=request.dict())
+        data = self.post(endpoint="generate-hint", data=request.dict())
         return GenerateHintResponse(**data)
 
     def generate_guess(self, request: GenerateGuessRequest) -> GenerateGuessResponse:
-        data = self._post("generate-guess", data=request.dict())
+        data = self.post(endpoint="generate-guess", data=request.dict())
         return GenerateGuessResponse(**data)
 
     def load_models(self, request: LoadModelsRequest) -> LoadModelsResponse:
-        data = self._post("load-models", data=request.dict())
+        data = self.post(endpoint="load-models", data=request.dict())
         return LoadModelsResponse(**data)
